@@ -124,7 +124,7 @@ The destructor.
 @param x1 where to store the bottom right horizontal bound.
 @param y1 where to store the bottom right vertical bound.
 
-Retrieves the current bounds coordinate for the Itm.
+Retrieves the current bounds coordinate for the Item.
 */
 	void GetBounds (double &x0, double &y0, double &x1, double &y1) const;
 /*!
@@ -155,6 +155,12 @@ returns G_MAXDOUBLE.
 	virtual double Distance (double x, double y, Item **item) const;
 /*!
 @param cr a cairo_t.
+
+Builds the cairo path corresponding to the Item bounds. Doesn't draw anything.
+*/
+	virtual void BuildPath (cairo_t *cr) const;
+/*!
+@param cr a cairo_t.
 @param is_vector whether the cairo_t is a vectorial context.
 
 Draws Item to \a cr. \a is_vector might be used to enhance rendering in the case
