@@ -305,44 +305,46 @@ Application::Application ():
 		}
 
 		// Initialize types
-		Object::AddType ("atom", CreateAtom, AtomType);
-		Object::AddType ("bond", CreateBond, gcu::BondType);
-		Object::AddType ("molecule", CreateMolecule, MoleculeType);
-		Object::AddType ("reaction", CreateReaction, ReactionType);
-		Object::SetCreationLabel (ReactionType, _("Create a new reaction"));
-		ReactionStepType = Object::AddType ("reaction-step", CreateReactionStep);
-		Object::AddType ("reactant", CreateReactant, ReactantType);
-		Object::AddType ("reaction-arrow", CreateReactionArrow, ReactionArrowType);
-		ReactionPropType = Object::AddType ("reaction-prop", CreateReactionProp);
-		MesomerType = Object::AddType ("mesomer", CreateMesomer);
-		Object::AddType ("mesomery", CreateMesomery, MesomeryType);
-		Object::SetCreationLabel (MesomeryType, _("Create a new mesomery relationship"));
-		Object::AddType ("mesomery-arrow", CreateMesomeryArrow, MesomeryArrowType);
-		Object::AddType ("text", CreateText, TextType);
-		Object::AddType ("fragment", CreateFragment, FragmentType);
-		ElectronType = Object::AddType ("electron", CreateElectron);
+		AddType ("atom", CreateAtom, AtomType);
+		AddType ("bond", CreateBond, gcu::BondType);
+		AddType ("molecule", CreateMolecule, MoleculeType);
+		AddType ("reaction", CreateReaction, ReactionType);
+		SetCreationLabel (ReactionType, _("Create a new reaction"));
+		ReactionStepType = AddType ("reaction-step", CreateReactionStep);
+		AddType ("reactant", CreateReactant, ReactantType);
+		AddType ("reaction-arrow", CreateReactionArrow, ReactionArrowType);
+		AddType ("reaction-operator", NULL, ReactionOperatorType);
+		ReactionPropType = AddType ("reaction-prop", CreateReactionProp);
+		MesomerType = AddType ("mesomer", CreateMesomer);
+		AddType ("mesomery", CreateMesomery, MesomeryType);
+		SetCreationLabel (MesomeryType, _("Create a new mesomery relationship"));
+		AddType ("mesomery-arrow", CreateMesomeryArrow, MesomeryArrowType);
+		AddType ("text", CreateText, TextType);
+		AddType ("fragment", CreateFragment, FragmentType);
+		ElectronType = AddType ("electron", CreateElectron);
 		Object::AddAlias (ElectronType, "electron-pair");
 		// Add rules
-		Object::AddRule ("reaction", RuleMustContain, "reaction-step");
-		Object::AddRule ("reaction-step", RuleMustContain, "reactant");
-		Object::AddRule ("reactant", RuleMustBeIn, "reaction-step");
-		Object::AddRule ("reaction-step", RuleMustBeIn, "reaction");
-		Object::AddRule ("reaction", RuleMustContain, "reaction-arrow");
-		Object::AddRule ("reaction-arrow", RuleMustBeIn, "reaction");
-		Object::AddRule ("reaction-arrow", RuleMayContain, "reaction-prop");
-		Object::AddRule ("reaction-prop", RuleMustBeIn, "reaction-arrow");
-		Object::AddRule ("reaction-prop", RuleMayContain, "molecule");
-		Object::AddRule ("reaction-prop", RuleMayContain, "text");
-		Object::AddRule ("reactant", RuleMayContain, "molecule");
-		Object::AddRule ("mesomer", RuleMustContain, "molecule");
-		Object::AddRule ("mesomer", RuleMustBeIn, "mesomery");
-		Object::AddRule ("mesomery", RuleMustContain, "mesomer");
-		Object::AddRule ("mesomery", RuleMustContain, "mesomery-arrow");
-		Object::AddRule ("mesomery-arrow", RuleMustBeIn, "mesomery");
-		MechanismArrowType = Object::AddType ("mechanism-arrow", CreateMechanismArrow);
-		MechanismStepType = Object::AddType ("mechanism-step", CreateMechanismStep);
-		Object::AddRule ("reaction-step", RuleMayContain, "mechanism-step");
-		Object::AddRule ("mesomery", RuleMayContain, "mechanism-step");
+		AddRule ("reaction", RuleMustContain, "reaction-step");
+		AddRule ("reaction-step", RuleMustContain, "reactant");
+		AddRule ("reactant", RuleMustBeIn, "reaction-step");
+		AddRule ("reaction-step", RuleMustBeIn, "reaction");
+		AddRule ("reaction", RuleMustContain, "reaction-arrow");
+		AddRule ("reaction-arrow", RuleMustBeIn, "reaction");
+		AddRule ("reaction-arrow", RuleMayContain, "reaction-prop");
+		AddRule ("reaction-prop", RuleMustBeIn, "reaction-arrow");
+		AddRule ("reaction-prop", RuleMayContain, "molecule");
+		AddRule ("reaction-prop", RuleMayContain, "text");
+		AddRule ("reaction-operator", RuleMustBeIn, "reaction-step");
+		AddRule ("reactant", RuleMayContain, "molecule");
+		AddRule ("mesomer", RuleMustContain, "molecule");
+		AddRule ("mesomer", RuleMustBeIn, "mesomery");
+		AddRule ("mesomery", RuleMustContain, "mesomer");
+		AddRule ("mesomery", RuleMustContain, "mesomery-arrow");
+		AddRule ("mesomery-arrow", RuleMustBeIn, "mesomery");
+		MechanismArrowType = AddType ("mechanism-arrow", CreateMechanismArrow);
+		MechanismStepType = AddType ("mechanism-step", CreateMechanismStep);
+		AddRule ("reaction-step", RuleMayContain, "mechanism-step");
+		AddRule ("mesomery", RuleMayContain, "mechanism-step");
 
 		// Create global signal ids
 		OnChangedSignal = Object::CreateNewSignalId ();
@@ -459,8 +461,6 @@ Application::~Application ()
 	if (m_entries)
 		g_free (RadioActions);
 	g_object_unref (IconFactory);
-	// unload plugins
-	Plugin::UnloadPlugins ();
 }
 
 void Application::ActivateTool (const string& toolname, bool activate)
@@ -475,9 +475,6 @@ void Application::ActivateTool (const string& toolname, bool activate)
 				GtkToggleToolButton* button = (GtkToggleToolButton*) ToolItems[toolname];
 				if (button && !gtk_toggle_tool_button_get_active (button))
 					gtk_toggle_tool_button_set_active (button, true);
-				Tools *ToolsBox = dynamic_cast<Tools*> (GetDialog ("tools"));
-				if (ToolsBox)
-					ToolsBox->OnSelectTool (m_pActiveTool);		
 			}
 		} else {
 			if (m_pActiveTool == m_Tools[toolname])
