@@ -28,6 +28,7 @@
 #include "fragment.h"
 #include "settings.h"
 #include "document.h"
+#include "molecule.h"
 #include "theme.h"
 #include "view.h"
 #include "widgetdata.h"
@@ -57,10 +58,10 @@ Bond::Bond (): gcu::Bond (), ItemClient ()
 }
 
 Bond::Bond (Atom* first, Atom* last, unsigned char order):
-		gcu::Bond (first, last, order), ItemClient ()
+		gcu::Bond (first, last, order), ItemClient (), m_type (NormalBondType)
 {
 	m_CoordsCalc = false;
-	m_type = NormalBondType;
+//	m_type = NormalBondType;
 	m_level = 0;
 }
 
@@ -520,7 +521,7 @@ void Bond::Revert ()
 
 void Bond::SetSelected (int state)
 {
-	if (!m_order)
+	if (!m_order || !m_Item)
 		return;
 	GOColor color;
 	switch (state) {	
@@ -569,7 +570,7 @@ void Bond::SetSelected (int state)
 
 void Bond::AddItem ()
 {
-	if (m_Item)
+	if (m_Item || !m_Begin || !m_End)
 		return;
 	double x1, y1, x2, y2;
 	Document *doc = static_cast <Document*> (GetDocument ());
@@ -684,358 +685,6 @@ void Bond::UpdateItem ()
 	}
 	AddItem ();
 }
-
-/*void Bond::Add (GtkWidget* w) const
-{
-	if (!w)
-		return;
-	WidgetData* pData = (WidgetData*) g_object_get_data (G_OBJECT (w), "data");
-	if (pData->Items[this] != NULL)
-		return;
-	Theme *pTheme = pData->m_View->GetDoc ()->GetTheme ();
-	gcu::Atom *pAtom0, *pAtom1;
-	if (!(pAtom0 = GetAtom (0)))
-		return;
-	if (!(pAtom1 = GetAtom (1)))
-		return;
-	unsigned char order = GetOrder ();
-	if (order == 0)
-		return;
-	GnomeCanvasGroup* group;
-	GnomeCanvasItem* item = NULL;
-	group = GNOME_CANVAS_GROUP (gnome_canvas_item_new (pData->Group, gnome_canvas_group_ext_get_type (), NULL));
-	g_signal_connect (G_OBJECT (group), "event", G_CALLBACK (on_event), w);
-	g_object_set_data (G_OBJECT (group), "object", (void *) this);
-	bool result = false;
-	if (m_Crossing.size () > 0) {
-		map<Bond*, BondCrossing>::const_iterator i, iend = m_Crossing.end ();
-		for (i = m_Crossing.begin (); i != iend; i++)
-			if ((result |= (*i).second.is_before))
-				break;
-	}
-	GnomeCanvasPathDef *path = NULL;
-	if (result) {
-		path = const_cast <Bond *> (this)->BuildCrossingPathDef (pData);
-		if (path) {
-			GnomeCanvasItem *item = (m_type == NormalBondType || m_type == UndeterminedBondType)?
-				gnome_canvas_item_new (
-					group,
-					gnome_canvas_bpath_ext_get_type (),
-					"bpath", path,
-					"outline_color", "white",
-					"width_units", pTheme->GetBondWidth () * 3.,
-					NULL):
-				gnome_canvas_item_new (
-					group,
-					gnome_canvas_bpath_ext_get_type (),
-					"bpath", path,
-					"fill_color", "white",
-					"width_units", 0.,
-					NULL);
-			g_object_set_data (G_OBJECT (group), "back", item);
-			g_object_set_data (G_OBJECT (item), "object", (void *) this);
-			g_signal_connect (G_OBJECT (item), "event", G_CALLBACK (on_event), w);*/
-			/* now bring to front, FIXME: not secure ! */
-/*			gnome_canvas_item_lower_to_bottom (item);
-			gnome_canvas_item_raise_to_top (GNOME_CANVAS_ITEM (group));
-			gcu::Atom *pAtom = GetAtom (0);
-			if (pAtom->GetZ () != 6 || static_cast <gcp::Atom*> (pAtom)->GetShowSymbol ())
-				gnome_canvas_item_raise_to_top (GNOME_CANVAS_ITEM (pData->Items[pAtom]));
-			pAtom = GetAtom (1);
-			if (pAtom->GetZ () != 6 || static_cast <gcp::Atom*> (pAtom)->GetShowSymbol ())
-				gnome_canvas_item_raise_to_top (GNOME_CANVAS_ITEM (pData->Items[pAtom]));
-			gnome_canvas_path_def_unref (path);
-		}
-	}
-	path = const_cast <Bond *> (this)->BuildPathDef (pData);
-	switch (GetType ())
-	{
-		case NormalBondType:
-		case UndeterminedBondType:
-			item = gnome_canvas_item_new(
-									group,
-									gnome_canvas_bpath_ext_get_type (),
-									"bpath", path,
-									"outline_color", (pData->IsSelected (this))? SelectColor: Color,
-									"width_units", pTheme->GetBondWidth (),
-									NULL);
-			break;
-		case ForeBondType:
-		case UpBondType:
-		case DownBondType:
-			item = gnome_canvas_item_new (
-									group,
-									gnome_canvas_bpath_ext_get_type (),
-									"bpath", path,
-									"fill_color", (pData->IsSelected (this))? SelectColor: Color,
-									"width_units", 0.,
-									NULL);
-			break;
-	}
-	gnome_canvas_path_def_unref (path);
-	g_object_set_data (G_OBJECT (group), "path", item);
-	g_object_set_data (G_OBJECT (item), "object", (void *) this);
-	g_signal_connect (G_OBJECT (item), "event", G_CALLBACK (on_event), w);
-	pData->Items[this] = group;
-	if (pAtom0->GetParent ()->GetType () == FragmentType)
-		gnome_canvas_item_raise_to_top (GNOME_CANVAS_ITEM (pData->Items[pAtom0->GetParent ()]));
-	else if (pAtom0->GetZ() != 6 || static_cast <Atom*> (pAtom0)->GetShowSymbol ())
-		gnome_canvas_item_raise_to_top (GNOME_CANVAS_ITEM (pData->Items[pAtom0]));
-	else
-		gnome_canvas_item_lower_to_bottom (GNOME_CANVAS_ITEM (pData->Items[pAtom0]));
-	map<string, Object*>::iterator i;
-	Object* electron = pAtom0->GetFirstChild (i);
-	while (electron) { 
-		gnome_canvas_item_raise_to_top (GNOME_CANVAS_ITEM (pData->Items[electron]));
-		electron = pAtom0->GetNextChild (i);
-	}
-	if (pAtom1->GetParent ()->GetType () == FragmentType)
-		gnome_canvas_item_raise_to_top (GNOME_CANVAS_ITEM (pData->Items[pAtom1->GetParent ()]));
-	else if (pAtom1->GetZ () != 6 || static_cast <Atom*> (pAtom1)->GetShowSymbol ())
-		gnome_canvas_item_raise_to_top (GNOME_CANVAS_ITEM (pData->Items[pAtom1]));
-	else
-		gnome_canvas_item_lower_to_bottom (GNOME_CANVAS_ITEM (pData->Items[pAtom1]));
-	electron = pAtom1->GetFirstChild (i);
-	while (electron) { 
-		gnome_canvas_item_raise_to_top (GNOME_CANVAS_ITEM (pData->Items[electron]));
-		electron = pAtom1->GetNextChild (i);
-	}
-}*/
-
-/*GnomeCanvasPathDef* Bond::BuildPathDef (WidgetData* pData)
-{
-	double x1, y1, x2, y2, x, y, dx, dy, dx1, dy1;
-	int i, n;
-	GnomeCanvasPathDef* path = gnome_canvas_path_def_new ();
-	Theme *pTheme = pData->m_View->GetDoc ()->GetTheme ();
-	switch (GetType ())
-	{
-		case NormalBondType:
-			i = 1;
-			while (GetLine2DCoords (i++, &x1, &y1, &x2, &y2))
-			{
-				gnome_canvas_path_def_moveto (path, x1 * pTheme->GetZoomFactor (), y1 * pTheme->GetZoomFactor ());
-				gnome_canvas_path_def_lineto (path, x2 * pTheme->GetZoomFactor (), y2 * pTheme->GetZoomFactor ());
-			}
-			break;
-		case UpBondType:
-			GetLine2DCoords(1, &x1, &y1, &x2, &y2);
-			gnome_canvas_path_def_moveto (path, x1 * pTheme->GetZoomFactor (), y1 * pTheme->GetZoomFactor ());
-			x = sqrt (square (x2 - x1) + square (y2 - y1));
-			dx = (y1 - y2) / x * pTheme->GetStereoBondWidth () / 2;
-			dy = (x2 - x1) / x * pTheme->GetStereoBondWidth () / 2;
-			gnome_canvas_path_def_lineto (path, x2 * pTheme->GetZoomFactor () + dx, y2 * pTheme->GetZoomFactor () + dy);
-			gnome_canvas_path_def_lineto (path, x2 * pTheme->GetZoomFactor () -dx, y2 * pTheme->GetZoomFactor () -dy);
-			gnome_canvas_path_def_closepath (path);
-			break;
-		case DownBondType:
-		{
-			double xi[8];
-			GetLine2DCoords (1, &x1, &y1, &x2, &y2);
-			x1 *= pTheme->GetZoomFactor ();
-			y1 *= pTheme->GetZoomFactor ();
-			x2 *= pTheme->GetZoomFactor ();
-			y2 *= pTheme->GetZoomFactor ();
-			x = sqrt (square (x2 - x1) + square (y2 - y1));
-			n = int (floor(x / (pTheme->GetHashDist () + pTheme->GetHashWidth ())));
-			dx1 = (x2 - x1) / x * pTheme->GetHashWidth ();
-			dy1 = (y2 - y1) / x * pTheme->GetHashWidth ();
-			dx = (y1 - y2) / x * pTheme->GetStereoBondWidth () / 2;
-			dy = (x2 - x1) / x * pTheme->GetStereoBondWidth () / 2;
-			gnome_canvas_path_def_moveto (path, xi[0] = x1 + dx, xi[1] = y1 + dy);
-			gnome_canvas_path_def_lineto (path, xi[2] = x1 - dx, xi[3] = y1 - dy);
-			dx *= (1 - pTheme->GetHashWidth () / x);
-			dy *= (1 - pTheme->GetHashWidth () / x);
-			gnome_canvas_path_def_lineto (path, xi[4] = x1 + dx1 - dx, xi[5] = y1 + dy1 - dy);
-			gnome_canvas_path_def_lineto (path, xi[6] = x1 + dx1 + dx, xi[7] = y1 + dy1 + dy);
-			gnome_canvas_path_def_lineto (path, xi[0], xi[1]);
-			gnome_canvas_path_def_closepath_current (path);
-			dx = (x2 - x1) / x * (pTheme->GetHashDist () + pTheme->GetHashWidth ())
-				- (y1 - y2) / x * pTheme->GetStereoBondWidth () / 2 * (pTheme->GetHashDist () + pTheme->GetHashWidth ()) / x;
-			dy = (y2 - y1) / x * (pTheme->GetHashDist () + pTheme->GetHashWidth ())
-				- (x2 - x1) / x * pTheme->GetStereoBondWidth () / 2 *  (pTheme->GetHashDist () + pTheme->GetHashWidth ()) / x;
-			dx1 = (x2 - x1) / x * (pTheme->GetHashDist () + pTheme->GetHashWidth ())
-				+ (y1 - y2) / x * pTheme->GetStereoBondWidth () / 2 *  (pTheme->GetHashDist () + pTheme->GetHashWidth ()) / x;
-			dy1 = (y2 - y1) / x * (pTheme->GetHashDist () + pTheme->GetHashWidth ())
-				+ (x2 - x1) / x * pTheme->GetStereoBondWidth () / 2 *  (pTheme->GetHashDist () + pTheme->GetHashWidth ()) / x;
-			for (int i = 1; i < n; i++) {
-				gnome_canvas_path_def_moveto (path, xi[0] += dx, xi[1] += dy);
-				gnome_canvas_path_def_lineto (path, xi[2] += dx1, xi[3] += dy1);
-				gnome_canvas_path_def_lineto (path, xi[4] += dx1, xi[5] += dy1);
-				gnome_canvas_path_def_lineto (path, xi[6] += dx, xi[7] += dy);
-				gnome_canvas_path_def_lineto (path, xi[0], xi[1]);
-				gnome_canvas_path_def_closepath_current (path);
-			}
-			break;
-		}
-		case ForeBondType:
-			GetLine2DCoords (1, &x1, &y1, &x2, &y2);
-			x = sqrt (square (x2 - x1) + square (y2 - y1));
-			dx = (y1 - y2) / x * pTheme->GetStereoBondWidth () / 2;
-			dy = (x2 - x1) / x * pTheme->GetStereoBondWidth () / 2;
-			gnome_canvas_path_def_moveto (path, x1 * pTheme->GetZoomFactor () + dx, y1 * pTheme->GetZoomFactor () + dy);
-			gnome_canvas_path_def_lineto (path, x2 * pTheme->GetZoomFactor () + dx, y2 * pTheme->GetZoomFactor () + dy);
-			gnome_canvas_path_def_lineto (path, x2 * pTheme->GetZoomFactor () -dx, y2 * pTheme->GetZoomFactor () -dy);
-			gnome_canvas_path_def_lineto (path, x1 * pTheme->GetZoomFactor () -dx, y1 * pTheme->GetZoomFactor () -dy);
-			gnome_canvas_path_def_closepath (path);
-			break;
-		case UndeterminedBondType:
-		{
-			GetLine2DCoords (1, &x1, &y1, &x2, &y2);
-			x1 *= pTheme->GetZoomFactor ();
-			y1 *= pTheme->GetZoomFactor ();
-			x2 *= pTheme->GetZoomFactor ();
-			y2 *= pTheme->GetZoomFactor ();
-			gnome_canvas_path_def_moveto (path, x1, y1);
-			double length;
-			length = sqrt (square (x2 - x1) + square (y2 - y1));
-			n = (int) length / 3;
-			int	s = 1;
-			dx = (x2 - x1) / n;
-			dy = (y2 - y1) / n;
-			x = x1;
-			y = y1;
-			for (int i = 1; i < n; i++) {
-				x1 = x + dx / 3 + dy /1.5 * s;
-				y1 = y + dy / 3 - dx /1.5 * s;
-				dx1 = x + dx / 1.5 + dy /1.5 * s;
-				dy1 = y + dy / 1.5 - dx /1.5 * s;
-				x += dx;
-				y += dy;
-				s *= -1;
-				gnome_canvas_path_def_curveto (path, x1, y1, dx1, dy1, x, y);
-			}
-			x1 = x + dx / 3 + dy /1.5 * s;
-			y1 = y + dy / 3 - dx /1.5 * s;
-			dx1 = x + dx / 1.5 + dy /1.5 * s;
-			dy1 = y + dy / 1.5 - dx /1.5 * s;
-			gnome_canvas_path_def_curveto (path, x1, y1, dx1, dy1, x2, y2);
-			break;
-		}
-	}
-	return path;
-}
-
-GnomeCanvasPathDef *Bond::BuildCrossingPathDef (WidgetData* pData)
-{
-	Theme *pTheme = pData->m_View->GetDoc ()->GetTheme ();
-	GnomeCanvasPathDef* path = NULL;
-	double x1, y1, x2, y2, x, dx, dy;
-	int i;
-	switch (GetType ()) {
-	case NormalBondType:
-		i = 1;
-		path = gnome_canvas_path_def_new ();
-		while (GetLine2DCoords (i++, &x1, &y1, &x2, &y2)) {
-			dx = (x2 - x1) / 10.;
-			dy = (y2 - y1) / 10.;
-			x1 += dx;
-			x2 -= dx;
-			y1 += dy;
-			y2 -= dy;
-			gnome_canvas_path_def_moveto (path, x1 * pTheme->GetZoomFactor (), y1 * pTheme->GetZoomFactor ());
-			gnome_canvas_path_def_lineto (path, x2 * pTheme->GetZoomFactor (), y2 * pTheme->GetZoomFactor ());
-		}
-		break;
-	case UpBondType:
-		break;
-	case DownBondType:
-		break;
-	case ForeBondType:
-		path = gnome_canvas_path_def_new ();
-		GetLine2DCoords (1, &x1, &y1, &x2, &y2);
-		dx = (x2 - x1) / 10.;
-		dy = (y2 - y1) / 10.;
-		x1 += dx;
-		x2 -= dx;
-		y1 += dy;
-		y2 -= dy;
-		x = sqrt(square(x2 - x1) + square(y2 - y1));
-		dx = (y1 - y2) / x * pTheme->GetStereoBondWidth () / 2;
-		dy = (x2 - x1) / x * pTheme->GetStereoBondWidth () / 2;
-		dx += (dx > 0.)? 1.: -1.;
-		dy += (dy > 0.)? 1.: -1.;
-		gnome_canvas_path_def_moveto (path, x1 * pTheme->GetZoomFactor () + dx, y1 * pTheme->GetZoomFactor () + dy);
-		gnome_canvas_path_def_lineto (path, x2 * pTheme->GetZoomFactor () + dx, y2 * pTheme->GetZoomFactor () + dy);
-		gnome_canvas_path_def_lineto (path, x2 * pTheme->GetZoomFactor () -dx, y2 * pTheme->GetZoomFactor () -dy);
-		gnome_canvas_path_def_lineto (path, x1 * pTheme->GetZoomFactor () -dx, y1 * pTheme->GetZoomFactor () -dy);
-		gnome_canvas_path_def_closepath (path);
-		break;
-	case UndeterminedBondType:
-		break;
-	}
-	return path;
-}*/
-
-/*void Bond::Update(GtkWidget* w) const
-{
-	if (!w || !m_order)
-		return;
-	WidgetData* pData = (WidgetData*) g_object_get_data(G_OBJECT(w), "data");
-	if (pData->Items[this] == NULL)
-		return;
-	Theme *pTheme = pData->m_View->GetDoc ()->GetTheme ();
-	bool result = false;
-	if (m_Crossing.size () > 0) {
-		map<Bond*, BondCrossing>::const_iterator i, iend = m_Crossing.end ();
-		for (i = m_Crossing.begin (); i != iend; i++)
-			if ((result |= (*i).second.is_before))
-				break;
-	}
-	GnomeCanvasPathDef* path;
-	void * obj;
-	GnomeCanvasGroup *group = pData->Items[this];
-	if (!group) {
-		Add (w);
-		return;
-	}
-	obj = g_object_get_data(G_OBJECT(group), "back");
-	if (result) {
-		path = const_cast <Bond *> (this)->BuildCrossingPathDef (pData);
-		if (path) {
-			if (obj)
-				g_object_set (obj, "bpath", path, NULL);
-			else {
-				GnomeCanvasItem *item = (m_type == NormalBondType || m_type == UndeterminedBondType)?
-					gnome_canvas_item_new (
-						group,
-						gnome_canvas_bpath_ext_get_type (),
-						"bpath", path,
-						"outline_color", "white",
-						"width_units", pTheme->GetBondWidth () * 3.,
-						NULL):
-					gnome_canvas_item_new (
-						group,
-						gnome_canvas_bpath_ext_get_type(),
-						"bpath", path,
-						"fill_color", "white",
-						"width_units", 0.,
-						NULL);
-				g_object_set_data (G_OBJECT (group), "back", item);
-				g_object_set_data (G_OBJECT (item), "object", (void *) this);
-				g_signal_connect (G_OBJECT (item), "event", G_CALLBACK (on_event), w);*/
-				/* now bring to front, FIXME: not secure ! */
-/*				gnome_canvas_item_lower_to_bottom (item);
-				gnome_canvas_item_raise_to_top (GNOME_CANVAS_ITEM (group));
-				gcu::Atom *pAtom = GetAtom (0);
-				if (pAtom->GetZ () != 6 || static_cast <gcp::Atom*> (pAtom)->GetShowSymbol ())
-					gnome_canvas_item_raise_to_top (GNOME_CANVAS_ITEM (pData->Items[pAtom]));
-				pAtom = GetAtom (1);
-				if (pAtom->GetZ () != 6 || static_cast <gcp::Atom*> (pAtom)->GetShowSymbol ())
-					gnome_canvas_item_raise_to_top (GNOME_CANVAS_ITEM (pData->Items[pAtom]));
-			}
-			gnome_canvas_path_def_unref (path);
-		}
-	} else if (obj) {
-		g_object_set_data (G_OBJECT(group), "back", NULL);
-	}
-	path = const_cast <Bond *> (this)->BuildPathDef (pData);
-	obj = g_object_get_data(G_OBJECT(group), "path");
-	g_object_set (obj, "bpath", path, NULL);
-	if (m_type == NormalBondType || m_type == UndeterminedBondType)
-		g_object_set (obj, "width_units", pTheme->GetBondWidth (), NULL);
-	gnome_canvas_path_def_unref (path);
-}*/
 	
 double Bond::GetYAlign ()
 {
@@ -1299,4 +948,13 @@ void Bond::AdjustPosition (double &x, double &y)
 	y += (y - y2) / d;
 }
 
+void Bond::OnLoaded ()
+{
+	gcu::Bond::OnLoaded ();
+	if (m_Begin && m_End && GetParent ()->GetType () != MoleculeType) {
+		Object *obj = new Molecule (static_cast <gcp::Atom *> (m_Begin));
+		obj->SetDirty ();
+	}
+}
+
 }	//	namespace gcp
