@@ -23,12 +23,14 @@
  */
 
 #include "config.h"
-#include "molecule.h"
-#include "document.h"
-#include "view.h"
 #include "application.h"
-#include "tool.h"
+#include "atom.h"
+#include "bond.h"
+#include "document.h"
+#include "molecule.h"
 #include "stringdlg.h"
+#include "tool.h"
+#include "view.h"
 #include <gcu/chain.h>
 #include <glib/gi18n-lib.h>
 #include <unistd.h>
@@ -88,7 +90,7 @@ Molecule::Molecule (TypeId Type): gcu::Molecule (Type)
 	m_IsResidue = false;
 }
 
-Molecule::Molecule (Atom* pAtom): gcu::Molecule  (pAtom)
+Molecule::Molecule (Atom* pAtom): gcu::Molecule (pAtom)
 {
 	m_Alignment = NULL;
 	m_Changed = true;
@@ -99,19 +101,6 @@ Molecule::~Molecule ()
 {
 }
 
-void Molecule::Add (GtkWidget* w) const
-{
-	std::list<gcu::Atom*>::const_iterator i, iend = m_Atoms.end ();
-	for (i = m_Atoms.begin (); i != iend; i++)
-		(*i)->Add (w);
-	std::list<Fragment*>::const_iterator j, jend = m_Fragments.end ();
-	for (j = m_Fragments.begin (); j != jend; j++)
-		(*j)->Add (w);
-	std::list<gcu::Bond*>::const_iterator k, kend = m_Bonds.end ();
-	for (k = m_Bonds.begin (); k != kend; k++)
-		(*k)->Add (w);
-}
-
 void Molecule::AddChild (Object* object)
 {
 	switch (object->GetType ()) {
@@ -428,7 +417,7 @@ bool Molecule::Load (xmlNodePtr node)
 		child = GetNextNodeByName (child->next, "bond");
 		CheckCrossings ((Bond*) pObject);
 	}
-	if (!m_Atoms.empty ()) {
+/*	if (!m_Atoms.empty ()) {
 		Atom* pAtom =  reinterpret_cast <Atom *> (m_Atoms.front ());
 		list<gcu::Atom*>::iterator i = m_Atoms.begin ();
 		i++;
@@ -440,7 +429,7 @@ bool Molecule::Load (xmlNodePtr node)
 			(*j)->RemoveAllCycles ();
 		Chain* pChain = new Chain (this, pAtom); //will find the cycles
 		delete pChain;
-	}
+	}*/
 	buf = (char*) xmlGetProp (node, (const xmlChar*) "valign");
 	if (buf) {
 		m_Alignment = GetDescendant (buf);
@@ -449,6 +438,7 @@ bool Molecule::Load (xmlNodePtr node)
 			return false;
 	}
 	m_Changed = true;
+	pDoc->ObjectLoaded (this);
 	return true;
 }
 
@@ -468,7 +458,7 @@ void Molecule::Transform2D (Matrix2D& m, double x, double y)
 		(*i)->GetBondsNumber ())  reinterpret_cast <Atom *> (*i)->Update ();
 }
 
-Object* Molecule::GetAtomAt (double x, double y, double z)
+Object* Molecule::GetAtomAt (double x, double y, G_GNUC_UNUSED double z)
 {
 	// Make use of Bond::GetAtomAt
 	std::list<gcu::Bond*>::iterator n, end = m_Bonds.end ();
@@ -633,6 +623,7 @@ void Molecule::BuildOBMol (OBMol &Mol)
 		AtomTable [pgAtom->GetId ()] = index;
 		obAtom.SetIdx (index++);
 		obAtom.SetAtomicNum (pgAtom->GetZ());
+		obAtom.SetFormalCharge (pgAtom->GetCharge ());
 		pgAtom->GetCoords (&x, &y, &z);
 		// Scans the atom bonds and change z to try conservation of stereochemistry
 		pBond = (Bond*) pgAtom->GetFirstBond (i);
@@ -693,9 +684,10 @@ void Molecule::BuildOBMol2D (OBMol &Mol)
 		AtomTable [pgAtom->GetId ()] = index;
 		obAtom.SetIdx (index++);
 		obAtom.SetAtomicNum (pgAtom->GetZ());
+		obAtom.SetFormalCharge (pgAtom->GetCharge ());
 		pgAtom->GetCoords (&x, &y, &z);
 		// Scans the atom bonds and change z to try conservation of stereochemistry
-		obAtom.SetVector ((x - xav)/ 100, (yav - y) / 100, 0.);
+		obAtom.SetVector ((x - xav) / 100, (yav - y) / 100, 0.);
 		Mol.AddAtom (obAtom);
 		obAtom.Clear ();
 	}
@@ -807,7 +799,7 @@ void Molecule::ShowWebBase (char const* uri_start, char const *uri_end)
 	((Document*) GetDocument ())->GetApplication ()->ShowURI (uri);
 }
 
-bool Molecule::OnSignal (SignalId Signal, Object *Child)
+bool Molecule::OnSignal (G_GNUC_UNUSED SignalId Signal, G_GNUC_UNUSED Object *Child)
 {
 	m_Changed = true;
 	return true;
