@@ -292,7 +292,7 @@ ThemeManager::~ThemeManager ()
 					mkdir (path.c_str (), 0x1ed);
 				} else
 					g_dir_close (dir);
-				path += string ("/") + theme->GetName ();
+				path += string ("/") + theme->GetFileName ();
 				xmlSaveFormatFile (path.c_str (), doc, true);
 			}
 		} else if (theme->m_Name == "Default")
@@ -496,8 +496,8 @@ void ThemeManager::ParseDir (string &path, ThemeType type)
 					theme = new Theme ("");
 					theme->Load (node);
 					if (theme->GetName () != name) {
-						theme->m_Name = name;
-						theme->modified = true;
+						theme->m_FileName = name;
+						name = theme->GetName ().c_str ();
 					}
 					if (theme->m_ThemeType == DEFAULT_THEME_TYPE || theme->m_ThemeType == GLOBAL_THEME_TYPE)
 						name = _(name);
