@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * gcu/application.cc 
  *
- * Copyright (C) 2005-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2005-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -27,6 +27,7 @@
 #include "cmd-context.h"
 #include "document.h"
 #include "loader.h"
+#include "message.h"
 #include "ui-builder.h"
 #include <gsf/gsf-input-gio.h>
 #include <gsf/gsf-output-gio.h>
@@ -37,6 +38,7 @@
 #include <cstring>
 #include <clocale>
 #include <set>
+#include <sstream>
 
 using namespace std;
 
@@ -45,8 +47,9 @@ namespace gcu
 
 GOConfNode *Application::m_ConfDir = NULL;
 
-static set<Application *> Apps;
+static map<string, Application *> Apps;
 WindowState Application::DefaultWindowState = NormalWindowState;
+static Application *Default = NULL;
 
 class ApplicationPrivate
 {
@@ -78,7 +81,7 @@ Application::Application (string name, string datadir, char const *help_name, ch
 		libgoffice_init ();
 		m_ConfDir = go_conf_get_node (NULL, GCU_CONF_DIR);
 	}
-	Apps.insert (this);
+	Apps[name] = this;
 	static bool first_call = true;
 	Name = name;
 	char const *szlang = getenv ("LANG");
@@ -124,11 +127,13 @@ Application::Application (string name, string datadir, char const *help_name, ch
 	}
 	g_slist_free (formats);
 	RegisterOptions (options);
+	if (Default == NULL)
+		Default = this;
 }
 
 Application::~Application ()
 {
-	Apps.erase (this);
+	Apps.erase (Name);
 	if (Apps.empty ()) {
 		ClearDialogs (); // needed to cleanly stop goffice
 		go_conf_free_node (m_ConfDir);
@@ -302,12 +307,12 @@ bool Application::Save (std::string const &uri, const gchar *mime_type, Document
 		g_file_delete (file, NULL, &error);
 		if (error) {
 			char *unescaped = g_uri_unescape_string (uri.c_str (), NULL);
-			GtkDialog* Box = GTK_DIALOG (gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, _("Error while processing %s:\n%s"), unescaped, error->message));
+			ostringstream str;
+			str << _("Error while processing ") << unescaped << ":\n" << error->message;
+			Message *Box = new Message (this, str.str ().c_str (), GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE);
 			g_free (unescaped);
 			g_error_free (error);
-			gtk_window_set_icon_name (GTK_WINDOW (Box), IconName.c_str ());
-			gtk_dialog_run (Box);
-			gtk_widget_destroy (GTK_WIDGET (Box));
+			Box->Run ();
 			g_object_unref (file);
 			return false;
 		}
@@ -359,10 +364,159 @@ void Application::AddOptions (GOptionContext *context)
 
 Application *Application::GetDefaultApplication ()
 {
-	static Application *Default = NULL;
 	if (!Default)
 		Default = new Application ("gcu"); // the name is just arbitrary
 	return Default;
 }
 
+Application *Application::GetApplication (char const *name)
+{
+	map <string, Application *>::iterator i = Apps.find (name);
+	return (i != Apps.end ())? (*i).second: NULL;
+}
+
+Application *Application::GetApplication (string &name)
+{
+	map <string, Application *>::iterator i = Apps.find (name);
+	return (i != Apps.end ())? (*i).second: NULL;
+}
+
+static TypeId NextType = OtherType;
+
+TypeId Application::AddType (std::string TypeName, Object* (*Create) (), TypeId id)
+{
+	TypeId Id = Object::GetTypeId (TypeName);
+	if (Id != NoType)
+		id = Id;
+	if (id == OtherType) {
+		id = NextType;
+		NextType = TypeId ((unsigned) NextType + 1);
+	}
+	if (Object::GetTypeId (TypeName) != id)
+		Object::AddAlias (id, TypeName);
+	TypeDesc &typedesc = m_Types[id];
+	typedesc.Id = id;
+	typedesc.Create = Create;
+	return typedesc.Id;
+}
+
+Object* Application::CreateObject (const std::string& TypeName, Object* parent)
+{
+	map <TypeId, TypeDesc>::const_iterator it = m_Types.find (Object::GetTypeId (TypeName));
+	if (it == m_Types.end ())
+		return NULL;
+	TypeDesc const *typedesc = &(*it).second;
+	Object* obj = (typedesc->Create)? typedesc->Create (): NULL;
+	if (obj) {
+		if (parent) {
+			char const *id = obj->GetId ();
+			if (id) {
+				char* newId = parent->GetDocument ()->GetNewId (id, false);
+				obj->SetId (newId);
+				delete [] newId;
+			}
+			parent->AddChild (obj);
+		}
+		obj->m_TypeDesc = typedesc;
+	}
+	return obj;
+}
+
+bool Application::BuildObjectContextualMenu (Object *target, GtkUIManager *UIManager, Object *object, double x, double y)
+{
+	bool result = false;
+	TypeDesc const *typedesc = target->m_TypeDesc;
+	if (!typedesc)
+		return false;
+	list<BuildMenuCb>::const_iterator i, end = typedesc->MenuCbs.end ();
+	for (i = typedesc->MenuCbs.begin (); i != end; i++)
+		result |= (*i) (target, UIManager, object, x, y);
+	return result;
+}
+
+void Application::AddRule (const string& type1, RuleId rule, const string& type2)
+{
+	AddRule (Object::GetTypeId (type1), rule, Object::GetTypeId (type2));
+}
+
+void Application::AddRule (TypeId type1, RuleId rule, TypeId type2)
+{
+	TypeDesc& typedesc1 = m_Types[type1];
+	if (typedesc1.Id == NoType) {
+		m_Types.erase (type1);
+		return;
+	}
+	TypeDesc& typedesc2 = m_Types[type2];
+	if (typedesc2.Id == NoType) {
+		m_Types.erase (type2);
+		return;
+	}
+	switch (rule) {
+	case RuleMustContain:
+		typedesc1.RequiredChildren.insert (typedesc2.Id);
+	case RuleMayContain:
+		typedesc1.PossibleChildren.insert (typedesc2.Id);
+		typedesc2.PossibleParents.insert (typedesc1.Id);
+		break;
+	case RuleMustBeIn:
+		typedesc1.RequiredParents.insert (typedesc2.Id);
+	case RuleMayBeIn:
+		typedesc2.PossibleChildren.insert (typedesc1.Id);
+		typedesc1.PossibleParents.insert (typedesc2.Id);
+		break;
+	}
+}
+
+const set<TypeId>& Application::GetRules (const string& type, RuleId rule)
+{
+	return GetRules (Object::GetTypeId (type), rule);
+}
+
+const set<TypeId>& Application::GetRules (TypeId type, RuleId rule)
+{
+	static set <TypeId> noId;
+	TypeDesc& typedesc = m_Types[type];
+	switch (rule) {
+	case RuleMustContain:
+		return typedesc.RequiredChildren;
+	case RuleMayContain:
+		return typedesc.PossibleChildren;
+	case RuleMustBeIn:
+		return typedesc.RequiredParents;
+	case RuleMayBeIn:
+		return typedesc.PossibleParents;
+	default:
+		return noId;
+	}
+	return noId;
+}
+
+void Application::SetCreationLabel (TypeId Id, string Label)
+{
+	TypeDesc &type = m_Types[Id];
+	type.CreationLabel = Label;
+}
+
+const string& Application::GetCreationLabel (TypeId Id)
+{
+	return m_Types[Id].CreationLabel;
+}
+
+const string& Application::GetCreationLabel (const string& TypeName)
+{
+	return m_Types[Object::GetTypeId (TypeName)].CreationLabel;
+}
+
+void Application::AddMenuCallback (TypeId Id, BuildMenuCb cb)
+{
+	TypeDesc& typedesc = m_Types[Id];
+	typedesc.MenuCbs.push_back (cb);
+}
+
+TypeDesc const *Application::GetTypeDescription (TypeId Id)
+{
+	map <TypeId, TypeDesc>::iterator i = m_Types.find (Id);
+	return (i != m_Types.end ())? &(*i).second: NULL;
+}
+
 }	//	namespace gcu
