@@ -31,11 +31,11 @@ Available widgets are:
 - GcpFontSel: a font selector.
 - GcuPeriodic: a periodic table of the elements.
 - GcuComboPeriodic: a combo box with a dropdown periodic table widget.
-- GcuCrystalViewer: a crystal structure viewer.
+- GcrCrystalViewer: a crystal structure viewer.
 - GcuChem3DViewer: a 3D molecular structure viewer.
 - GcuSpectrumViewer: a spectrum viewer.
 
-The C++ classes are grouped in the gcu, gccv, and gcp namespaces. A C interface
+The C++ classes are grouped in the gcu, gccv, gcr, and gcp namespaces. A C interface
 exists to use some (not so many) of the functionalities offered in these classes;
 the corresponding documentation is available in the chemistry.h file.
 */
